@@ -41,3 +41,21 @@ def env(_ctx: ClickContext):
     logger.info(
         "Note: these can be overridden by passing command line arguments to gable."
     )
+
+
+@debug.command()
+@global_options()
+@click.pass_context
+def pyping(ctx: ClickContext):
+    """Pings the Gable API (python server) to check for connectivity"""
+    try:
+        response, success, status_code = ctx.obj.client.get_pyping()
+    except Exception as e:
+        raise click.ClickException(
+            f"Unable to ping Gable API at {ctx.obj.client.endpoint}: {str(e)}"
+        )
+    if not success:
+        raise click.ClickException(
+            f"Unable to ping Gable API at {ctx.obj.client.endpoint}"
+        )
+    logger.info(f"Successfully pinged Gable API at {ctx.obj.client.endpoint}")
