@@ -1,21 +1,22 @@
 import json
-from typing import Annotated, Any, List, Optional, Tuple, Union, cast
+from typing import Annotated, Any, List, Optional, Union
 
-import click
-from gable.client import GableClient
+from gable.client import GableClient, del_none
 from gable.openapi import (
     CheckDataAssetCommentMarkdownResponse,
     CheckDataAssetDetailedResponse,
     CheckDataAssetErrorResponse,
+    CheckDataAssetMissingAssetResponse,
     CheckDataAssetNoContractResponse,
-    CheckDataAssetRequest,
-    CheckDataAssetsRequest,
     ErrorResponse,
     Input,
     ResponseType,
+    ResponseType1,
+    ResponseType2,
+    ResponseType3,
+    ResponseType4,
 )
-from gable.readers.dbapi import DbapiReader
-from gable.readers.file import read_file
+from gable.options import DATABASE_SOURCE_TYPE_VALUES, FILE_SOURCE_TYPE_VALUES
 from pydantic import Field, parse_obj_as
 
 # Discriminated union for the response from the /data-assets/check endpoint
@@ -24,55 +25,12 @@ CheckDataAssetDetailedResponseUnion = Annotated[
         CheckDataAssetDetailedResponse,
         CheckDataAssetErrorResponse,
         CheckDataAssetNoContractResponse,
+        CheckDataAssetMissingAssetResponse,
     ],
     Field(discriminator="responseType"),
 ]
 
 
-def post_contract_check_request(
-    client: GableClient,
-    contract_id: str,
-    source_type: str,
-    schema_contents: str,
-) -> tuple[str, bool]:
-    result, success, status_code = client.post(
-        f"v0/contract/{contract_id}/check",
-        json={
-            "sourceType": source_type,
-            "schemaContents": schema_contents,
-        },
-    )
-    return str(cast(dict[str, Any], result)["message"]), success
-
-
-def post_data_asset_check_requests(
-    client: GableClient,
-    source_type: str,
-    source_names: List[str],
-    realDbName: str,
-    realDbSchema: str,
-    schema_contents: List[str],
-) -> dict[str, Tuple[str, int]]:
-    results: dict[str, Tuple[str, int]] = {}
-    requests = get_check_data_asset_requests(
-        source_type=source_type,
-        source_names=source_names,
-        schema_contents=schema_contents,
-        realDbName=realDbName,
-        realDbSchema=realDbSchema,
-    )
-    for source_name, request in requests.items():
-        result, success, status_code = client.post(
-            "v0/data-asset/check",
-            json=request.dict(),
-        )
-        results[source_name] = (
-            cast(dict[str, Any], result)["message"],
-            status_code,
-        )
-    return results
-
-
 def post_data_assets_check_requests(
     client: GableClient,
     responseType: ResponseType,
@@ -89,55 +47,65 @@ def post_data_assets_check_requests(
             CheckDataAssetDetailedResponse,
             CheckDataAssetErrorResponse,
             CheckDataAssetNoContractResponse,
+            CheckDataAssetMissingAssetResponse,
         ]
     ],
 ]:
-    requests = get_check_data_asset_requests(
+    requests = build_check_data_asset_inputs(
         source_type=source_type,
         source_names=source_names,
         schema_contents=schema_contents,
         realDbName=realDbName,
         realDbSchema=realDbSchema,
     )
-    inputs = [Input.parse_obj(request.dict()) for request in requests.values()]
-    request = CheckDataAssetsRequest(
-        responseType=responseType,
-        inputs=inputs,
-    )
-    result, success, status_code = client.post(
-        "v0/data-assets/check",
-        json=json.loads(request.json()),
-    )
+
+    inputs = [del_none(input.dict()) for input in requests.values()]
+    request = {
+        "responseType": responseType.value,
+        "inputs": inputs,
+    }
+
+    result = client.post_data_assets_check(request)
     if responseType == ResponseType.DETAILED:
         if type(result) == list:
-            return [
-                parse_obj_as(
-                    CheckDataAssetDetailedResponse
-                    | CheckDataAssetErrorResponse
-                    | CheckDataAssetNoContractResponse,
-                    r,
-                )
-                for r in result
-            ]
+            parsed_responses: list[CheckDataAssetDetailedResponseUnion] = []
+            for r in result:
+                parsed_response = parse_check_data_asset_response(r)
+                parsed_responses.append(parsed_response)
+            return parsed_responses
         else:
             return ErrorResponse.parse_obj(result)
-    else:
-        return parse_obj_as(
-            CheckDataAssetCommentMarkdownResponse | ErrorResponse, result
-        )
+    if responseType == ResponseType.COMMENT_MARKDOWN:
+        return parse_obj_as(CheckDataAssetCommentMarkdownResponse, result)
+    raise ValueError(f"Unknown response type: {responseType}, cannot parse result")
 
 
-def get_check_data_asset_requests(
+# Pylance was struggling to understand the union type when calling parse_obj_as
+# I created this function to prevent a '# type ignore' annotation in the code
+def parse_check_data_asset_response(response) -> CheckDataAssetDetailedResponseUnion:
+    response_type = response["responseType"]
+    if response_type == ResponseType1.NO_CONTRACT.value:
+        return parse_obj_as(CheckDataAssetNoContractResponse, response)
+    if response_type == ResponseType2.DETAILED.value:
+        return parse_obj_as(CheckDataAssetDetailedResponse, response)
+    if response_type == ResponseType3.ERROR.value:
+        return parse_obj_as(CheckDataAssetErrorResponse, response)
+    if response_type == ResponseType4.MISSING_DATA_ASSET.value:
+        return parse_obj_as(CheckDataAssetMissingAssetResponse, response)
+    raise ValueError(f"Unknown response type: {response_type} in response: {response}")
+
+
+def build_check_data_asset_inputs(
     source_type: str,
     source_names: list[str],
     schema_contents: list[str],
     realDbName: Optional[str] = None,
     realDbSchema: Optional[str] = None,
-) -> dict[str, CheckDataAssetRequest]:
-    requests: dict[str, CheckDataAssetRequest] = {}
+) -> dict[str, Input]:
+    requests: dict[str, Input] = {}
     # If this is a database, there might be multiple table's schemas within the information schema
     # returned from the DbApi reader. In that case, we need to post each table's schema separately.
-    if source_type in ["postgres", "mysql"]:
+    if source_type in DATABASE_SOURCE_TYPE_VALUES:
         schema_contents_str = schema_contents[0]
         source_name = source_names[0]
         information_schema = json.loads(schema_contents_str)
@@ -149,18 +117,23 @@ def get_check_data_asset_requests(
                 information_schema_row
             )
         for table_name, table_schema in grouped_table_schemas.items():
-            requests[
-                f"{realDbName}.{realDbSchema}.{table_name}"
-            ] = CheckDataAssetRequest(
+            requests[f"{realDbName}.{realDbSchema}.{table_name}"] = Input(
                 sourceType=source_type,
                 sourceName=source_name,
                 realDbName=realDbName,
                 realDbSchema=realDbSchema,
                 schemaContents=json.dumps(table_schema),
             )
-    else:
+    elif source_type in FILE_SOURCE_TYPE_VALUES:
         for source_name, schema in zip(source_names, schema_contents):
-            requests[source_name] = CheckDataAssetRequest(
+            requests[source_name] = Input(
+                sourceType=source_type,
+                sourceName=source_name,
+                schemaContents=schema,
+            )
+    else:  # source_type in PYTHON_SOURCE_TYPE_VALUES
+        for source_name, schema in zip(source_names, schema_contents):
+            requests[source_name] = Input(
                 sourceType=source_type,
                 sourceName=source_name,
                 schemaContents=schema,
