@@ -1,8 +1,10 @@
 import functools
 import os
+import re
 import sys
 import traceback
-from typing import Literal, Optional, get_args
+from enum import Enum
+from typing import Literal, Optional
 
 import click
 from click_option_group import OptionGroup, optgroup
@@ -14,12 +16,37 @@ from loguru import logger
 gable_api_endpoint = None
 gable_api_key = None
 
-DATABASE_SOURCE_TYPE = Literal["postgres", "mysql"]
-DATABASE_SOURCE_TYPE_VALUES = list(get_args(DATABASE_SOURCE_TYPE))
-FILE_SOURCE_TYPE = Literal["avro", "protobuf", "json_schema"]
-FILE_SOURCE_TYPE_VALUES = list(get_args(FILE_SOURCE_TYPE))
-ALL_SOURCE_TYPE = Literal[DATABASE_SOURCE_TYPE, FILE_SOURCE_TYPE]
-ALL_SOURCE_TYPE_VALUES = list(get_args(ALL_SOURCE_TYPE))
+
+class SourceType(Enum):
+    POSTGRES = "postgres"
+    MYSQL = "mysql"
+    AVRO = "avro"
+    PROTOBUF = "protobuf"
+    JSON_SCHEMA = "json_schema"
+    PYTHON = "python"
+    TYPESCRIPT = "typescript"
+
+
+ALL_SOURCE_TYPE_VALUES = [source_type.value for source_type in SourceType]
+DATABASE_SOURCE_TYPE_VALUES = [SourceType.POSTGRES.value, SourceType.MYSQL.value]
+FILE_SOURCE_TYPE_VALUES = [
+    SourceType.AVRO.value,
+    SourceType.PROTOBUF.value,
+    SourceType.JSON_SCHEMA.value,
+]
+STATIC_CODE_ANALYSIS_SOURCE_TYPE_VALUES = [
+    SourceType.PYTHON.value,
+    SourceType.TYPESCRIPT.value,
+]
+SCHEMA_SOURCE_TYPE_VALUES = DATABASE_SOURCE_TYPE_VALUES + FILE_SOURCE_TYPE_VALUES
+
+
+class TypescriptLibrary(Enum):
+    BRANDVIEWS = "brandviews"
+    SEGMENT = "segment"
+
+
+ALL_TYPESCRIPT_LIBRARY_VALUES = [library.value for library in TypescriptLibrary]
 
 
 class Context:
@@ -193,7 +220,7 @@ def source_type_dependent_required_option_callback(ctx, param, value):
     This callback requires the --source-type option to be processed first so it's available in the context.
     """
 
-    source_type: ALL_SOURCE_TYPE = ctx.params["source_type"]
+    source_type: SourceType = ctx.params["source_type"]
 
     if source_type in DATABASE_SOURCE_TYPE_VALUES:
         # Only require the options for the database source type
@@ -203,17 +230,89 @@ def source_type_dependent_required_option_callback(ctx, param, value):
         # Only require the options for the file source type
         if param.group.name == "Protobuf & Avro options" and not value:
             raise click.MissingParameter(ctx=ctx, param=param)
+    elif source_type == SourceType.PYTHON.value:
+        if param.group.name == "Python Project Options" and not value:
+            raise click.MissingParameter(ctx=ctx, param=param)
+        python_event_name_key_validator(param, value)
+    elif source_type == SourceType.TYPESCRIPT.value:
+        if param.group.name == "Typescript Project Options" and not value:
+            raise click.MissingParameter(ctx=ctx, param=param)
     else:
         # Should never happen, but just in case
         raise click.BadParameter("", ctx=ctx, param=param)
     return value
 
 
+def python_event_name_key_validator(param: click.Parameter, value: str) -> None:
+    # Event name key must be a valid access path:
+    # 1. The string can start with a word (letters, digits, underscores), [*], or [<index>].
+    # 2. If there is a dot separator, it should be followed by a word, [*], or [<index>]. This process can repeat (zero or more times).
+    # 3. The string must end with a word.
+    if param.opts[0] == "--event-name-key" and not re.match(
+        r"^(\w+|\[\*\]|\[-?[0-9]+\])(\.(\w+|\[\*\]|\[-?[0-9]+\]))*\w+$", value
+    ):
+        raise click.BadParameter(value + " must be valid event name access path")
+
+
+@logger.catch()
+def python_project_options(
+    option_group_help_text: str, action: Literal["register", "check"]
+):
+    """Decorator that adds Python project related options to a command like 'data-asset register'.
+
+    The 'action' option is used to tweak the help text depending on the command being run. If a new value is
+    added, make sure it works as {action}ed and {action}ing (e.g. registered and registering, checked and checking)
+    """
+
+    def decorator(func):
+        @optgroup.group(
+            "Python Project Options",
+            help=option_group_help_text,
+        )
+        @optgroup.option(
+            "--project-root",
+            help="This should be the directory location of the Python project that will be bundled.",
+            callback=source_type_dependent_required_option_callback,
+            type=str,
+        )
+        @optgroup.option(
+            "--emitter-function",
+            help="Name of the emitter function",
+            callback=source_type_dependent_required_option_callback,
+            type=str,
+        )
+        @optgroup.option(
+            "--emitter-payload-parameter",
+            help="Name of the parameter representing the event payload",
+            callback=source_type_dependent_required_option_callback,
+            type=str,
+        )
+        @optgroup.option(
+            "--event-name-key",
+            help="Input must be a \".\" delimited list of field property access directives or array indexes to the event name key field. The field property access directive is a valid dictionary key. The array index is square brackets[] with either a digit in it (targeting a specific element of the array), or * (targeting all elements in the array).\n\nExample: \"fieldName.[0].eventName\" describes the access pay to the event name in: {'fieldName': [{'eventName': 'event_one'}]}.",
+            callback=source_type_dependent_required_option_callback,
+            type=str,
+        )
+        @optgroup.option(
+            "--emitter-file-path",
+            help="Relative path from the root of the project to the file that contains the emitter function",
+            callback=source_type_dependent_required_option_callback,
+            type=str,
+        )
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return decorator
+
+
 @logger.catch()
 def file_source_type_options(
     option_group_help_text: str, action: Literal["register", "check"]
 ):
-    """Decorator that adds file sour type (protobuf, avro, etc) related options to a command like 'data-asset register'.
+    """Decorator that adds file source type (protobuf, avro, etc) related options to a command like 'data-asset register'.
 
     The 'action' option is used to tweak the help text depending on the command being run. If a new value is
     added, make sure it works as {action}ed and {action}ing (e.g. registered and registering, checked and checking)
@@ -240,6 +339,36 @@ def file_source_type_options(
     return decorator
 
 
+@logger.catch()
+def typescript_project_options(
+    option_group_help_text: str, action: Literal["register"]
+):
+    """Decorator that adds Typescript project related options to a command like 'data-asset register'.
+
+    The 'action' option is used to tweak the help text depending on the command being run. If a new value is
+    added, make sure it works as {action}ed and {action}ing (e.g. registered and registering, checked and checking)
+    """
+
+    def decorator(func):
+        @optgroup.group(
+            "Typescript Project Options",
+            help=option_group_help_text,
+        )
+        @optgroup.option(
+            "--library",
+            help="This should indicate the library emitting the events you want detected as data assets.",
+            callback=source_type_dependent_required_option_callback,
+            type=click.Choice(ALL_TYPESCRIPT_LIBRARY_VALUES),
+        )
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return decorator
+
+
 def proxy_database_options(
     option_group_help_text: str, action: Literal["register", "check"]
 ):
